aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.BL
diff options
context:
space:
mode:
authorVictoria Plitt <Victoria.Plitt@twine-s.com>2022-07-24 16:45:32 +0300
committerVictoria Plitt <Victoria.Plitt@twine-s.com>2022-07-24 16:45:32 +0300
commitc4e8c98689dcedf035484cd079eac8d9678286db (patch)
treef7c21491c5528b7d83a730c078dfd896524904b4 /Software/Visual_Studio/Tango.BL
parentd208f2029740f203ce79c6452432fa083a4c5c07 (diff)
downloadTango-c4e8c98689dcedf035484cd079eac8d9678286db.tar.gz
Tango-c4e8c98689dcedf035484cd079eac8d9678286db.zip
Added Washing test results tables
Related Work Items: #6660
Diffstat (limited to 'Software/Visual_Studio/Tango.BL')
-rw-r--r--Software/Visual_Studio/Tango.BL/Builders/RMLExtensionTestResultsCollectionBuilder.cs16
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTO.cs14
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTOBase.cs57
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTO.cs14
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTOBase.cs33
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestResultBase.cs62
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResult.cs16
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResultBase.cs251
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterial.cs12
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterialBase.cs114
-rw-r--r--Software/Visual_Studio/Tango.BL/ObservablesContext.cs132
-rw-r--r--Software/Visual_Studio/Tango.BL/ObservablesEntitiesAdapterExtension.cs630
-rw-r--r--Software/Visual_Studio/Tango.BL/ObservablesStaticCollectionsExtension.cs630
-rw-r--r--Software/Visual_Studio/Tango.BL/Tango.BL.csproj10
14 files changed, 1366 insertions, 625 deletions
diff --git a/Software/Visual_Studio/Tango.BL/Builders/RMLExtensionTestResultsCollectionBuilder.cs b/Software/Visual_Studio/Tango.BL/Builders/RMLExtensionTestResultsCollectionBuilder.cs
index 2b962d56b..19c027976 100644
--- a/Software/Visual_Studio/Tango.BL/Builders/RMLExtensionTestResultsCollectionBuilder.cs
+++ b/Software/Visual_Studio/Tango.BL/Builders/RMLExtensionTestResultsCollectionBuilder.cs
@@ -64,5 +64,21 @@ namespace Tango.BL.Builders
}
});
}
+
+ public virtual RMLExtensionTestResultsCollectionBuilder WithWashingTestResults()
+ {
+ return AddStep(4, () =>
+ {
+ foreach (var result in Entities.ToList())
+ {
+ var tests = Context.RmlExtensionTestWashingResults.Where(x => x.RmlExtensionTestResultsGuid == result.Guid).ToList();
+ foreach( var test in tests)
+ {
+ test.WashingTestMaterials = Context.WashingTestMaterials.FirstOrDefault(x => x.Guid == test.WashingTestMaterialsGuid);
+ }
+
+ }
+ });
+ }
}
}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTO.cs b/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTO.cs
new file mode 100644
index 000000000..1e15767c8
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTO.cs
@@ -0,0 +1,14 @@
+
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.BL.DTO
+{
+ public class RmlExtensionTestWashingResultDTO : RmlExtensionTestWashingResultDTOBase
+ {
+
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTOBase.cs b/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTOBase.cs
new file mode 100644
index 000000000..9f98d4aa9
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/DTO/RmlExtensionTestWashingResultDTOBase.cs
@@ -0,0 +1,57 @@
+
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Tango Observables Generator
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated. Do not modify!
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.BL.Entities;
+
+namespace Tango.BL.DTO
+{
+ public abstract class RmlExtensionTestWashingResultDTOBase : ObservableEntityDTO<RmlExtensionTestWashingResultDTO, RmlExtensionTestWashingResult>
+ {
+
+ /// <summary>
+ /// rml extension test results guid
+ /// </summary>
+ public String RmlExtensionTestResultsGuid
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// washing test materials guid
+ /// </summary>
+ public String WashingTestMaterialsGuid
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// color
+ /// </summary>
+ public Int32 Color
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// washing value
+ /// </summary>
+ public Nullable<Double> WashingValue
+ {
+ get; set;
+ }
+
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTO.cs b/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTO.cs
new file mode 100644
index 000000000..f2c9ec25d
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTO.cs
@@ -0,0 +1,14 @@
+
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.BL.DTO
+{
+ public class WashingTestMaterialDTO : WashingTestMaterialDTOBase
+ {
+
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTOBase.cs b/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTOBase.cs
new file mode 100644
index 000000000..8c9bc0ff1
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/DTO/WashingTestMaterialDTOBase.cs
@@ -0,0 +1,33 @@
+
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Tango Observables Generator
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated. Do not modify!
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.BL.Entities;
+
+namespace Tango.BL.DTO
+{
+ public abstract class WashingTestMaterialDTOBase : ObservableEntityDTO<WashingTestMaterialDTO, WashingTestMaterial>
+ {
+
+ /// <summary>
+ /// name
+ /// </summary>
+ public String Name
+ {
+ get; set;
+ }
+
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResult.cs b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResult.cs
new file mode 100644
index 000000000..af8858e64
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResult.cs
@@ -0,0 +1,16 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.BL.Entities
+{
+ public class RmlExtensionTestWashingResult: RmlExtensionTestWashingResultBase
+ {
+ public RmlExtensionTestWashingResult(): base()
+ {
+
+ }
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResultBase.cs b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResultBase.cs
new file mode 100644
index 000000000..0927baa04
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestWashingResultBase.cs
@@ -0,0 +1,251 @@
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Tango Observables Generator
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated. Do not modify!
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+using System;
+using System.Collections.Generic;
+using System.Collections.ObjectModel;
+using System.ComponentModel.DataAnnotations;
+using System.ComponentModel.DataAnnotations.Schema;
+using System.Xml.Serialization;
+using Newtonsoft.Json;
+using System.Linq;
+using Tango.DAL.Remote.DB;
+using Tango.Core;
+using System.ComponentModel;
+using Tango.Core.CustomAttributes;
+
+namespace Tango.BL.Entities
+{
+ [Table("RML_EXTENSION_TEST_WASHING_RESULTS")]
+ public abstract class RmlExtensionTestWashingResultBase : ObservableEntity<RmlExtensionTestWashingResult>
+ {
+
+ public event EventHandler<Int32> ColorChanged;
+
+ public event EventHandler<Nullable<Double>> WashingValueChanged;
+
+ public event EventHandler<RmlExtensionTestResult> RmlExtensionTestResultsChanged;
+
+ public event EventHandler<WashingTestMaterial> WashingTestMaterialsChanged;
+
+ protected String _rmlextensiontestresultsguid;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase rml extension test results guid.
+ /// </summary>
+
+ [Column("RML_EXTENSION_TEST_RESULTS_GUID")]
+ [ForeignKey("RmlExtensionTestResults")]
+
+ public String RmlExtensionTestResultsGuid
+ {
+ get
+ {
+ return _rmlextensiontestresultsguid;
+ }
+
+ set
+ {
+ if (_rmlextensiontestresultsguid != value)
+ {
+ _rmlextensiontestresultsguid = value;
+
+ }
+ }
+ }
+
+ protected String _washingtestmaterialsguid;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase washing test materials guid.
+ /// </summary>
+
+ [Column("WASHING_TEST_MATERIALS_GUID")]
+ [ForeignKey("WashingTestMaterials")]
+
+ public String WashingTestMaterialsGuid
+ {
+ get
+ {
+ return _washingtestmaterialsguid;
+ }
+
+ set
+ {
+ if (_washingtestmaterialsguid != value)
+ {
+ _washingtestmaterialsguid = value;
+
+ }
+ }
+ }
+
+ protected Int32 _color;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase color.
+ /// </summary>
+
+ [Column("COLOR")]
+
+ public Int32 Color
+ {
+ get
+ {
+ return _color;
+ }
+
+ set
+ {
+ if (_color != value)
+ {
+ _color = value;
+
+ OnColorChanged(value);
+
+ }
+ }
+ }
+
+ protected Nullable<Double> _washingvalue;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase washing value.
+ /// </summary>
+
+ [Column("WASHING_VALUE")]
+
+ public Nullable<Double> WashingValue
+ {
+ get
+ {
+ return _washingvalue;
+ }
+
+ set
+ {
+ if (_washingvalue != value)
+ {
+ _washingvalue = value;
+
+ OnWashingValueChanged(value);
+
+ }
+ }
+ }
+
+ protected RmlExtensionTestResult _rmlextensiontestresults;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase rml extension test results.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual RmlExtensionTestResult RmlExtensionTestResults
+ {
+ get
+ {
+ return _rmlextensiontestresults;
+ }
+
+ set
+ {
+ if (_rmlextensiontestresults != value)
+ {
+ _rmlextensiontestresults = value;
+
+ if (RmlExtensionTestResults != null)
+ {
+ RmlExtensionTestResultsGuid = RmlExtensionTestResults.Guid;
+ }
+
+ OnRmlExtensionTestResultsChanged(value);
+
+ }
+ }
+ }
+
+ protected WashingTestMaterial _washingtestmaterials;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestwashingresultbase washing test materials.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual WashingTestMaterial WashingTestMaterials
+ {
+ get
+ {
+ return _washingtestmaterials;
+ }
+
+ set
+ {
+ if (_washingtestmaterials != value)
+ {
+ _washingtestmaterials = value;
+
+ if (WashingTestMaterials != null)
+ {
+ WashingTestMaterialsGuid = WashingTestMaterials.Guid;
+ }
+
+ OnWashingTestMaterialsChanged(value);
+
+ }
+ }
+ }
+
+ /// <summary>
+ /// Called when the Color has changed.
+ /// </summary>
+ protected virtual void OnColorChanged(Int32 color)
+ {
+ ColorChanged?.Invoke(this, color);
+ RaisePropertyChanged(nameof(Color));
+ }
+
+ /// <summary>
+ /// Called when the WashingValue has changed.
+ /// </summary>
+ protected virtual void OnWashingValueChanged(Nullable<Double> washingvalue)
+ {
+ WashingValueChanged?.Invoke(this, washingvalue);
+ RaisePropertyChanged(nameof(WashingValue));
+ }
+
+ /// <summary>
+ /// Called when the RmlExtensionTestResults has changed.
+ /// </summary>
+ protected virtual void OnRmlExtensionTestResultsChanged(RmlExtensionTestResult rmlextensiontestresults)
+ {
+ RmlExtensionTestResultsChanged?.Invoke(this, rmlextensiontestresults);
+ RaisePropertyChanged(nameof(RmlExtensionTestResults));
+ }
+
+ /// <summary>
+ /// Called when the WashingTestMaterials has changed.
+ /// </summary>
+ protected virtual void OnWashingTestMaterialsChanged(WashingTestMaterial washingtestmaterials)
+ {
+ WashingTestMaterialsChanged?.Invoke(this, washingtestmaterials);
+ RaisePropertyChanged(nameof(WashingTestMaterials));
+ }
+
+ /// <summary>
+ /// Initializes a new instance of the <see cref="RmlExtensionTestWashingResultBase" /> class.
+ /// </summary>
+ public RmlExtensionTestWashingResultBase() : base()
+ {
+ }
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterial.cs b/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterial.cs
new file mode 100644
index 000000000..7cb6bd8e3
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterial.cs
@@ -0,0 +1,12 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace Tango.BL.Entities
+{
+ public class WashingTestMaterial: WashingTestMaterialBase
+ {
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterialBase.cs b/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterialBase.cs
new file mode 100644
index 000000000..84271403c
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Entities/WashingTestMaterialBase.cs
@@ -0,0 +1,114 @@
+//------------------------------------------------------------------------------
+// <auto-generated>
+// This code was generated by a tool.
+// Tango Observables Generator
+//
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated. Do not modify!
+// </auto-generated>
+//------------------------------------------------------------------------------
+
+using System;
+using System.Collections.Generic;
+using System.Collections.ObjectModel;
+using System.ComponentModel.DataAnnotations;
+using System.ComponentModel.DataAnnotations.Schema;
+using System.Xml.Serialization;
+using Newtonsoft.Json;
+using System.Linq;
+using Tango.DAL.Remote.DB;
+using Tango.Core;
+using System.ComponentModel;
+using Tango.Core.CustomAttributes;
+
+namespace Tango.BL.Entities
+{
+ [Table("WASHING_TEST_MATERIALS")]
+ public abstract class WashingTestMaterialBase : ObservableEntity<WashingTestMaterial>
+ {
+
+ public event EventHandler<String> NameChanged;
+
+ public event EventHandler<SynchronizedObservableCollection<RmlExtensionTestWashingResult>> RmlExtensionTestWashingResultsChanged;
+
+ protected String _name;
+
+ /// <summary>
+ /// Gets or sets the washingtestmaterialbase name.
+ /// </summary>
+
+ [Column("NAME")]
+
+ public String Name
+ {
+ get
+ {
+ return _name;
+ }
+
+ set
+ {
+ if (_name != value)
+ {
+ _name = value;
+
+ OnNameChanged(value);
+
+ }
+ }
+ }
+
+ protected SynchronizedObservableCollection<RmlExtensionTestWashingResult> _rmlextensiontestwashingresults;
+
+ /// <summary>
+ /// Gets or sets the washingtestmaterialbase rml extension test washing results.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<RmlExtensionTestWashingResult> RmlExtensionTestWashingResults
+ {
+ get
+ {
+ return _rmlextensiontestwashingresults;
+ }
+
+ set
+ {
+ if (_rmlextensiontestwashingresults != value)
+ {
+ _rmlextensiontestwashingresults = value;
+
+ OnRmlExtensionTestWashingResultsChanged(value);
+
+ }
+ }
+ }
+
+ /// <summary>
+ /// Called when the Name has changed.
+ /// </summary>
+ protected virtual void OnNameChanged(String name)
+ {
+ NameChanged?.Invoke(this, name);
+ RaisePropertyChanged(nameof(Name));
+ }
+
+ /// <summary>
+ /// Called when the RmlExtensionTestWashingResults has changed.
+ /// </summary>
+ protected virtual void OnRmlExtensionTestWashingResultsChanged(SynchronizedObservableCollection<RmlExtensionTestWashingResult> rmlextensiontestwashingresults)
+ {
+ RmlExtensionTestWashingResultsChanged?.Invoke(this, rmlextensiontestwashingresults);
+ RaisePropertyChanged(nameof(RmlExtensionTestWashingResults));
+ }
+
+ /// <summary>
+ /// Initializes a new instance of the <see cref="WashingTestMaterialBase" /> class.
+ /// </summary>
+ public WashingTestMaterialBase() : base()
+ {
+
+ RmlExtensionTestWashingResults = new SynchronizedObservableCollection<RmlExtensionTestWashingResult>();
+
+ }
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/ObservablesContext.cs b/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
index f62ae38bd..c06af8ba5 100644
--- a/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
+++ b/Software/Visual_Studio/Tango.BL/ObservablesContext.cs
@@ -167,6 +167,70 @@ namespace Tango.BL
}
/// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrations.
+ /// </summary>
+ public DbSet<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTests.
+ /// </summary>
+ public DbSet<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
+ /// </summary>
+ public DbSet<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
+ /// </summary>
+ public DbSet<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShades.
+ /// </summary>
+ public DbSet<RmlExtensionColorShade> RmlExtensionColorShades
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTests.
+ /// </summary>
+ public DbSet<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTestsData.
+ /// </summary>
+ public DbSet<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
+ {
+ get; set;
+ }
+
+ /// <summary>
+ /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// </summary>
+ public DbSet<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ {
+ get; set;
+ }
+
+ /// <summary>
/// Gets or sets the ActionLogs.
/// </summary>
public DbSet<ActionLog> ActionLogs
@@ -703,65 +767,9 @@ namespace Tango.BL
}
/// <summary>
- /// Gets or sets the RmlExtensionColorCalibrations.
- /// </summary>
- public DbSet<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTests.
- /// </summary>
- public DbSet<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
- /// </summary>
- public DbSet<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
- /// </summary>
- public DbSet<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorShades.
- /// </summary>
- public DbSet<RmlExtensionColorShade> RmlExtensionColorShades
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTests.
- /// </summary>
- public DbSet<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTestsData.
- /// </summary>
- public DbSet<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
- {
- get; set;
- }
-
- /// <summary>
- /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// Gets or sets the RmlExtensionTestWashingResults.
/// </summary>
- public DbSet<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ public DbSet<RmlExtensionTestWashingResult> RmlExtensionTestWashingResults
{
get; set;
}
@@ -959,6 +967,14 @@ namespace Tango.BL
}
/// <summary>
+ /// Gets or sets the WashingTestMaterials.
+ /// </summary>
+ public DbSet<WashingTestMaterial> WashingTestMaterials
+ {
+ get; set;
+ }
+
+ /// <summary>
/// Gets or sets the WindingMethods.
/// </summary>
public DbSet<WindingMethod> WindingMethods
diff --git a/Software/Visual_Studio/Tango.BL/ObservablesEntitiesAdapterExtension.cs b/Software/Visual_Studio/Tango.BL/ObservablesEntitiesAdapterExtension.cs
index a9d32e87d..d06377cf3 100644
--- a/Software/Visual_Studio/Tango.BL/ObservablesEntitiesAdapterExtension.cs
+++ b/Software/Visual_Studio/Tango.BL/ObservablesEntitiesAdapterExtension.cs
@@ -665,6 +665,294 @@ namespace Tango.BL
}
+ private ObservableCollection<RmlExtensionColorCalibration> _rmlextensioncolorcalibrations;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrations.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrations;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrations = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrations));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrations View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTest> _rmlextensioncolorcalibrationstests;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTests.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstests;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstests = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTests));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTests View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> _rmlextensioncolorcalibrationstestsliquiddata;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddata;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddata = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidData));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsliquiddataViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddataViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> _rmlextensioncolorcalibrationstestsliquiddatapoints;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddatapoints;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddatapoints = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPoints));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShade> _rmlextensioncolorshades;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShades.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShade> RmlExtensionColorShades
+ {
+ get
+ {
+ return _rmlextensioncolorshades;
+ }
+
+ set
+ {
+ _rmlextensioncolorshades = value; RaisePropertyChanged(nameof(RmlExtensionColorShades));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadesViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShades View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadesViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShadesTest> _rmlextensioncolorshadestests;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTests.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
+ {
+ get
+ {
+ return _rmlextensioncolorshadestests;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestests = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTests));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadestestsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTests View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesTestsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShadesTestsData> _rmlextensioncolorshadestestsdata;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTestsData.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsdata;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsdata = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsData));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadestestsdataViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTestsData View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesTestsDataViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsdataViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsdataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsDataViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+ /// <summary>
+ /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// </summary>
+ public ObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ {
+ get
+ {
+ return _rmlextensiontestresultsfiles;
+ }
+
+ set
+ {
+ _rmlextensiontestresultsfiles = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ }
+
+ }
+
+ private ICollectionView _rmlextensiontestresultsfilesViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionTestResultsFiles View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionTestResultsFilesViewSource
+ {
+ get
+ {
+ return _rmlextensiontestresultsfilesViewSource;
+ }
+
+ set
+ {
+ _rmlextensiontestresultsfilesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFilesViewSource));
+ }
+
+ }
+
private ObservableCollection<ActionLog> _actionlogs;
/// <summary>
/// Gets or sets the ActionLogs.
@@ -3077,290 +3365,38 @@ namespace Tango.BL
}
- private ObservableCollection<RmlExtensionColorCalibration> _rmlextensioncolorcalibrations;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrations.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
- {
- get
- {
- return _rmlextensioncolorcalibrations;
- }
-
- set
- {
- _rmlextensioncolorcalibrations = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrations));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrations View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTest> _rmlextensioncolorcalibrationstests;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTests.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
- {
- get
- {
- return _rmlextensioncolorcalibrationstests;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstests = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTests));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTests View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> _rmlextensioncolorcalibrationstestsliquiddata;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddata;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddata = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidData));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsliquiddataViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddataViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> _rmlextensioncolorcalibrationstestsliquiddatapoints;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddatapoints;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddatapoints = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPoints));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShade> _rmlextensioncolorshades;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShades.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShade> RmlExtensionColorShades
- {
- get
- {
- return _rmlextensioncolorshades;
- }
-
- set
- {
- _rmlextensioncolorshades = value; RaisePropertyChanged(nameof(RmlExtensionColorShades));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadesViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShades View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesViewSource
- {
- get
- {
- return _rmlextensioncolorshadesViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShadesTest> _rmlextensioncolorshadestests;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTests.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
- {
- get
- {
- return _rmlextensioncolorshadestests;
- }
-
- set
- {
- _rmlextensioncolorshadestests = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTests));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadestestsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTests View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesTestsViewSource
- {
- get
- {
- return _rmlextensioncolorshadestestsViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadestestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShadesTestsData> _rmlextensioncolorshadestestsdata;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTestsData.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
- {
- get
- {
- return _rmlextensioncolorshadestestsdata;
- }
-
- set
- {
- _rmlextensioncolorshadestestsdata = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsData));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadestestsdataViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTestsData View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesTestsDataViewSource
- {
- get
- {
- return _rmlextensioncolorshadestestsdataViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadestestsdataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsDataViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+ private ObservableCollection<RmlExtensionTestWashingResult> _rmlextensiontestwashingresults;
/// <summary>
- /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// Gets or sets the RmlExtensionTestWashingResults.
/// </summary>
- public ObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ public ObservableCollection<RmlExtensionTestWashingResult> RmlExtensionTestWashingResults
{
get
{
- return _rmlextensiontestresultsfiles;
+ return _rmlextensiontestwashingresults;
}
set
{
- _rmlextensiontestresultsfiles = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ _rmlextensiontestwashingresults = value; RaisePropertyChanged(nameof(RmlExtensionTestWashingResults));
}
}
- private ICollectionView _rmlextensiontestresultsfilesViewSource;
+ private ICollectionView _rmlextensiontestwashingresultsViewSource;
/// <summary>
- /// Gets or sets the RmlExtensionTestResultsFiles View Source.
+ /// Gets or sets the RmlExtensionTestWashingResults View Source.
///</summary>
- public ICollectionView RmlExtensionTestResultsFilesViewSource
+ public ICollectionView RmlExtensionTestWashingResultsViewSource
{
get
{
- return _rmlextensiontestresultsfilesViewSource;
+ return _rmlextensiontestwashingresultsViewSource;
}
set
{
- _rmlextensiontestresultsfilesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFilesViewSource));
+ _rmlextensiontestwashingresultsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestWashingResultsViewSource));
}
}
@@ -4229,6 +4265,42 @@ namespace Tango.BL
}
+ private ObservableCollection<WashingTestMaterial> _washingtestmaterials;
+ /// <summary>
+ /// Gets or sets the WashingTestMaterials.
+ /// </summary>
+ public ObservableCollection<WashingTestMaterial> WashingTestMaterials
+ {
+ get
+ {
+ return _washingtestmaterials;
+ }
+
+ set
+ {
+ _washingtestmaterials = value; RaisePropertyChanged(nameof(WashingTestMaterials));
+ }
+
+ }
+
+ private ICollectionView _washingtestmaterialsViewSource;
+ /// <summary>
+ /// Gets or sets the WashingTestMaterials View Source.
+ ///</summary>
+ public ICollectionView WashingTestMaterialsViewSource
+ {
+ get
+ {
+ return _washingtestmaterialsViewSource;
+ }
+
+ set
+ {
+ _washingtestmaterialsViewSource = value; RaisePropertyChanged(nameof(WashingTestMaterialsViewSource));
+ }
+
+ }
+
private ObservableCollection<WindingMethod> _windingmethods;
/// <summary>
/// Gets or sets the WindingMethods.
@@ -4307,6 +4379,22 @@ namespace Tango.BL
YarnWhiteShadesViewSource = CreateCollectionView(YarnWhiteShades);
+ RmlExtensionColorCalibrationsViewSource = CreateCollectionView(RmlExtensionColorCalibrations);
+
+ RmlExtensionColorCalibrationsTestsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTests);
+
+ RmlExtensionColorCalibrationsTestsLiquidDataViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidData);
+
+ RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidDataPoints);
+
+ RmlExtensionColorShadesViewSource = CreateCollectionView(RmlExtensionColorShades);
+
+ RmlExtensionColorShadesTestsViewSource = CreateCollectionView(RmlExtensionColorShadesTests);
+
+ RmlExtensionColorShadesTestsDataViewSource = CreateCollectionView(RmlExtensionColorShadesTestsData);
+
+ RmlExtensionTestResultsFilesViewSource = CreateCollectionView(RmlExtensionTestResultsFiles);
+
ActionLogsViewSource = CreateCollectionView(ActionLogs);
AddressesViewSource = CreateCollectionView(Addresses);
@@ -4441,21 +4529,7 @@ namespace Tango.BL
PublishedProcedureProjectsVersionsViewSource = CreateCollectionView(PublishedProcedureProjectsVersions);
- RmlExtensionColorCalibrationsViewSource = CreateCollectionView(RmlExtensionColorCalibrations);
-
- RmlExtensionColorCalibrationsTestsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTests);
-
- RmlExtensionColorCalibrationsTestsLiquidDataViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidData);
-
- RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidDataPoints);
-
- RmlExtensionColorShadesViewSource = CreateCollectionView(RmlExtensionColorShades);
-
- RmlExtensionColorShadesTestsViewSource = CreateCollectionView(RmlExtensionColorShadesTests);
-
- RmlExtensionColorShadesTestsDataViewSource = CreateCollectionView(RmlExtensionColorShadesTestsData);
-
- RmlExtensionTestResultsFilesViewSource = CreateCollectionView(RmlExtensionTestResultsFiles);
+ RmlExtensionTestWashingResultsViewSource = CreateCollectionView(RmlExtensionTestWashingResults);
RmlsViewSource = CreateCollectionView(Rmls);
@@ -4505,6 +4579,8 @@ namespace Tango.BL
UsersRolesViewSource = CreateCollectionView(UsersRoles);
+ WashingTestMaterialsViewSource = CreateCollectionView(WashingTestMaterials);
+
WindingMethodsViewSource = CreateCollectionView(WindingMethods);
}
diff --git a/Software/Visual_Studio/Tango.BL/ObservablesStaticCollectionsExtension.cs b/Software/Visual_Studio/Tango.BL/ObservablesStaticCollectionsExtension.cs
index e3b7a68ea..b40fbb618 100644
--- a/Software/Visual_Studio/Tango.BL/ObservablesStaticCollectionsExtension.cs
+++ b/Software/Visual_Studio/Tango.BL/ObservablesStaticCollectionsExtension.cs
@@ -665,6 +665,294 @@ namespace Tango.BL
}
+ private ObservableCollection<RmlExtensionColorCalibration> _rmlextensioncolorcalibrations;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrations.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrations;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrations = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrations));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrations View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTest> _rmlextensioncolorcalibrationstests;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTests.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstests;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstests = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTests));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTests View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> _rmlextensioncolorcalibrationstestsliquiddata;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddata;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddata = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidData));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsliquiddataViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddataViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> _rmlextensioncolorcalibrationstestsliquiddatapoints;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddatapoints;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddatapoints = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPoints));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShade> _rmlextensioncolorshades;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShades.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShade> RmlExtensionColorShades
+ {
+ get
+ {
+ return _rmlextensioncolorshades;
+ }
+
+ set
+ {
+ _rmlextensioncolorshades = value; RaisePropertyChanged(nameof(RmlExtensionColorShades));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadesViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShades View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadesViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShadesTest> _rmlextensioncolorshadestests;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTests.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
+ {
+ get
+ {
+ return _rmlextensioncolorshadestests;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestests = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTests));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadestestsViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTests View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesTestsViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionColorShadesTestsData> _rmlextensioncolorshadestestsdata;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTestsData.
+ /// </summary>
+ public ObservableCollection<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsdata;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsdata = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsData));
+ }
+
+ }
+
+ private ICollectionView _rmlextensioncolorshadestestsdataViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionColorShadesTestsData View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionColorShadesTestsDataViewSource
+ {
+ get
+ {
+ return _rmlextensioncolorshadestestsdataViewSource;
+ }
+
+ set
+ {
+ _rmlextensioncolorshadestestsdataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsDataViewSource));
+ }
+
+ }
+
+ private ObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+ /// <summary>
+ /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// </summary>
+ public ObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ {
+ get
+ {
+ return _rmlextensiontestresultsfiles;
+ }
+
+ set
+ {
+ _rmlextensiontestresultsfiles = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ }
+
+ }
+
+ private ICollectionView _rmlextensiontestresultsfilesViewSource;
+ /// <summary>
+ /// Gets or sets the RmlExtensionTestResultsFiles View Source.
+ ///</summary>
+ public ICollectionView RmlExtensionTestResultsFilesViewSource
+ {
+ get
+ {
+ return _rmlextensiontestresultsfilesViewSource;
+ }
+
+ set
+ {
+ _rmlextensiontestresultsfilesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFilesViewSource));
+ }
+
+ }
+
private ObservableCollection<ActionLog> _actionlogs;
/// <summary>
/// Gets or sets the ActionLogs.
@@ -3077,290 +3365,38 @@ namespace Tango.BL
}
- private ObservableCollection<RmlExtensionColorCalibration> _rmlextensioncolorcalibrations;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrations.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibration> RmlExtensionColorCalibrations
- {
- get
- {
- return _rmlextensioncolorcalibrations;
- }
-
- set
- {
- _rmlextensioncolorcalibrations = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrations));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrations View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTest> _rmlextensioncolorcalibrationstests;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTests.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTest> RmlExtensionColorCalibrationsTests
- {
- get
- {
- return _rmlextensioncolorcalibrationstests;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstests = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTests));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTests View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> _rmlextensioncolorcalibrationstestsliquiddata;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidData> RmlExtensionColorCalibrationsTestsLiquidData
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddata;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddata = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidData));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsliquiddataViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidData View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddataViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> _rmlextensioncolorcalibrationstestsliquiddatapoints;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints.
- /// </summary>
- public ObservableCollection<RmlExtensionColorCalibrationsTestsLiquidDataPoint> RmlExtensionColorCalibrationsTestsLiquidDataPoints
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddatapoints;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddatapoints = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPoints));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorCalibrationsTestsLiquidDataPoints View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource
- {
- get
- {
- return _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource;
- }
-
- set
- {
- _rmlextensioncolorcalibrationstestsliquiddatapointsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShade> _rmlextensioncolorshades;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShades.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShade> RmlExtensionColorShades
- {
- get
- {
- return _rmlextensioncolorshades;
- }
-
- set
- {
- _rmlextensioncolorshades = value; RaisePropertyChanged(nameof(RmlExtensionColorShades));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadesViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShades View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesViewSource
- {
- get
- {
- return _rmlextensioncolorshadesViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShadesTest> _rmlextensioncolorshadestests;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTests.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShadesTest> RmlExtensionColorShadesTests
- {
- get
- {
- return _rmlextensioncolorshadestests;
- }
-
- set
- {
- _rmlextensioncolorshadestests = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTests));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadestestsViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTests View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesTestsViewSource
- {
- get
- {
- return _rmlextensioncolorshadestestsViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadestestsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionColorShadesTestsData> _rmlextensioncolorshadestestsdata;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTestsData.
- /// </summary>
- public ObservableCollection<RmlExtensionColorShadesTestsData> RmlExtensionColorShadesTestsData
- {
- get
- {
- return _rmlextensioncolorshadestestsdata;
- }
-
- set
- {
- _rmlextensioncolorshadestestsdata = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsData));
- }
-
- }
-
- private ICollectionView _rmlextensioncolorshadestestsdataViewSource;
- /// <summary>
- /// Gets or sets the RmlExtensionColorShadesTestsData View Source.
- ///</summary>
- public ICollectionView RmlExtensionColorShadesTestsDataViewSource
- {
- get
- {
- return _rmlextensioncolorshadestestsdataViewSource;
- }
-
- set
- {
- _rmlextensioncolorshadestestsdataViewSource = value; RaisePropertyChanged(nameof(RmlExtensionColorShadesTestsDataViewSource));
- }
-
- }
-
- private ObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+ private ObservableCollection<RmlExtensionTestWashingResult> _rmlextensiontestwashingresults;
/// <summary>
- /// Gets or sets the RmlExtensionTestResultsFiles.
+ /// Gets or sets the RmlExtensionTestWashingResults.
/// </summary>
- public ObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ public ObservableCollection<RmlExtensionTestWashingResult> RmlExtensionTestWashingResults
{
get
{
- return _rmlextensiontestresultsfiles;
+ return _rmlextensiontestwashingresults;
}
set
{
- _rmlextensiontestresultsfiles = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ _rmlextensiontestwashingresults = value; RaisePropertyChanged(nameof(RmlExtensionTestWashingResults));
}
}
- private ICollectionView _rmlextensiontestresultsfilesViewSource;
+ private ICollectionView _rmlextensiontestwashingresultsViewSource;
/// <summary>
- /// Gets or sets the RmlExtensionTestResultsFiles View Source.
+ /// Gets or sets the RmlExtensionTestWashingResults View Source.
///</summary>
- public ICollectionView RmlExtensionTestResultsFilesViewSource
+ public ICollectionView RmlExtensionTestWashingResultsViewSource
{
get
{
- return _rmlextensiontestresultsfilesViewSource;
+ return _rmlextensiontestwashingresultsViewSource;
}
set
{
- _rmlextensiontestresultsfilesViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestResultsFilesViewSource));
+ _rmlextensiontestwashingresultsViewSource = value; RaisePropertyChanged(nameof(RmlExtensionTestWashingResultsViewSource));
}
}
@@ -4229,6 +4265,42 @@ namespace Tango.BL
}
+ private ObservableCollection<WashingTestMaterial> _washingtestmaterials;
+ /// <summary>
+ /// Gets or sets the WashingTestMaterials.
+ /// </summary>
+ public ObservableCollection<WashingTestMaterial> WashingTestMaterials
+ {
+ get
+ {
+ return _washingtestmaterials;
+ }
+
+ set
+ {
+ _washingtestmaterials = value; RaisePropertyChanged(nameof(WashingTestMaterials));
+ }
+
+ }
+
+ private ICollectionView _washingtestmaterialsViewSource;
+ /// <summary>
+ /// Gets or sets the WashingTestMaterials View Source.
+ ///</summary>
+ public ICollectionView WashingTestMaterialsViewSource
+ {
+ get
+ {
+ return _washingtestmaterialsViewSource;
+ }
+
+ set
+ {
+ _washingtestmaterialsViewSource = value; RaisePropertyChanged(nameof(WashingTestMaterialsViewSource));
+ }
+
+ }
+
private ObservableCollection<WindingMethod> _windingmethods;
/// <summary>
/// Gets or sets the WindingMethods.
@@ -4307,6 +4379,22 @@ namespace Tango.BL
YarnWhiteShadesViewSource = CreateCollectionView(YarnWhiteShades);
+ RmlExtensionColorCalibrationsViewSource = CreateCollectionView(RmlExtensionColorCalibrations);
+
+ RmlExtensionColorCalibrationsTestsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTests);
+
+ RmlExtensionColorCalibrationsTestsLiquidDataViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidData);
+
+ RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidDataPoints);
+
+ RmlExtensionColorShadesViewSource = CreateCollectionView(RmlExtensionColorShades);
+
+ RmlExtensionColorShadesTestsViewSource = CreateCollectionView(RmlExtensionColorShadesTests);
+
+ RmlExtensionColorShadesTestsDataViewSource = CreateCollectionView(RmlExtensionColorShadesTestsData);
+
+ RmlExtensionTestResultsFilesViewSource = CreateCollectionView(RmlExtensionTestResultsFiles);
+
ActionLogsViewSource = CreateCollectionView(ActionLogs);
AddressesViewSource = CreateCollectionView(Addresses);
@@ -4441,21 +4529,7 @@ namespace Tango.BL
PublishedProcedureProjectsVersionsViewSource = CreateCollectionView(PublishedProcedureProjectsVersions);
- RmlExtensionColorCalibrationsViewSource = CreateCollectionView(RmlExtensionColorCalibrations);
-
- RmlExtensionColorCalibrationsTestsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTests);
-
- RmlExtensionColorCalibrationsTestsLiquidDataViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidData);
-
- RmlExtensionColorCalibrationsTestsLiquidDataPointsViewSource = CreateCollectionView(RmlExtensionColorCalibrationsTestsLiquidDataPoints);
-
- RmlExtensionColorShadesViewSource = CreateCollectionView(RmlExtensionColorShades);
-
- RmlExtensionColorShadesTestsViewSource = CreateCollectionView(RmlExtensionColorShadesTests);
-
- RmlExtensionColorShadesTestsDataViewSource = CreateCollectionView(RmlExtensionColorShadesTestsData);
-
- RmlExtensionTestResultsFilesViewSource = CreateCollectionView(RmlExtensionTestResultsFiles);
+ RmlExtensionTestWashingResultsViewSource = CreateCollectionView(RmlExtensionTestWashingResults);
RmlsViewSource = CreateCollectionView(Rmls);
@@ -4505,6 +4579,8 @@ namespace Tango.BL
UsersRolesViewSource = CreateCollectionView(UsersRoles);
+ WashingTestMaterialsViewSource = CreateCollectionView(WashingTestMaterials);
+
WindingMethodsViewSource = CreateCollectionView(WindingMethods);
}
diff --git a/Software/Visual_Studio/Tango.BL/Tango.BL.csproj b/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
index 8bdb3b3f5..259b2ce6b 100644
--- a/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
+++ b/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
@@ -307,6 +307,8 @@
<Compile Include="DTO\RmlExtensionTestResultDTOBase.cs" />
<Compile Include="DTO\RmlExtensionTestResultsFileDTO.cs" />
<Compile Include="DTO\RmlExtensionTestResultsFileDTOBase.cs" />
+ <Compile Include="DTO\RmlExtensionTestWashingResultDTO.cs" />
+ <Compile Include="DTO\RmlExtensionTestWashingResultDTOBase.cs" />
<Compile Include="DTO\RmlsExtensionDTO.cs" />
<Compile Include="DTO\RmlsExtensionDTOBase.cs" />
<Compile Include="DTO\RmlsSpoolDTO.cs" />
@@ -357,6 +359,8 @@
<Compile Include="DTO\UserDTOBase.cs" />
<Compile Include="DTO\UsersRoleDTO.cs" />
<Compile Include="DTO\UsersRoleDTOBase.cs" />
+ <Compile Include="DTO\WashingTestMaterialDTO.cs" />
+ <Compile Include="DTO\WashingTestMaterialDTOBase.cs" />
<Compile Include="DTO\WindingMethodDTO.cs" />
<Compile Include="DTO\WindingMethodDTOBase.cs" />
<Compile Include="DTO\YarnApplicationDTO.cs" />
@@ -495,6 +499,8 @@
<Compile Include="Entities\RmlExtensionTestResultBase.cs" />
<Compile Include="Entities\RmlExtensionTestResultsFile.cs" />
<Compile Include="Entities\RmlExtensionTestResultsFileBase.cs" />
+ <Compile Include="Entities\RmlExtensionTestWashingResult.cs" />
+ <Compile Include="Entities\RmlExtensionTestWashingResultBase.cs" />
<Compile Include="Entities\RmlsExtension.cs" />
<Compile Include="Entities\RmlsExtensionBase.cs" />
<Compile Include="Entities\RmlsSpoolBase.cs" />
@@ -537,6 +543,8 @@
<Compile Include="Entities\TensileResultBase.cs" />
<Compile Include="Entities\UserBase.cs" />
<Compile Include="Entities\UsersRoleBase.cs" />
+ <Compile Include="Entities\WashingTestMaterial.cs" />
+ <Compile Include="Entities\WashingTestMaterialBase.cs" />
<Compile Include="Entities\WindingMethodBase.cs" />
<Compile Include="Entities\YarnApplication.cs" />
<Compile Include="Entities\YarnApplicationBase.cs" />
@@ -812,7 +820,7 @@
</Target>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
+ <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestResultBase.cs b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestResultBase.cs
index 7f6804039..c53b14327 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestResultBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/RmlExtensionTestResultBase.cs
@@ -91,9 +91,11 @@ namespace Tango.BL.Entities
public event EventHandler<SynchronizedObservableCollection<TensileResult>> TensileResultsChanged;
+ public event EventHandler<SynchronizedObservableCollection<RmlExtensionTestResultsFile>> RmlExtensionTestResultsFilesChanged;
+
public event EventHandler<Machine> MachineChanged;
- public event EventHandler<SynchronizedObservableCollection<RmlExtensionTestResultsFile>> RmlExtensionTestResultsFilesChanged;
+ public event EventHandler<SynchronizedObservableCollection<RmlExtensionTestWashingResult>> RmlExtensionTestWashingResultsChanged;
public event EventHandler<SynchronizedObservableCollection<RubbingResult>> RubbingResultsChanged;
@@ -1016,6 +1018,31 @@ namespace Tango.BL.Entities
}
}
+ protected SynchronizedObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+
+ /// <summary>
+ /// Gets or sets the rmlextensiontestresultbase rml extension test results files.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ {
+ get
+ {
+ return _rmlextensiontestresultsfiles;
+ }
+
+ set
+ {
+ if (_rmlextensiontestresultsfiles != value)
+ {
+ _rmlextensiontestresultsfiles = value;
+
+ OnRmlExtensionTestResultsFilesChanged(value);
+
+ }
+ }
+ }
+
protected Machine _machine;
/// <summary>
@@ -1048,26 +1075,26 @@ namespace Tango.BL.Entities
}
}
- protected SynchronizedObservableCollection<RmlExtensionTestResultsFile> _rmlextensiontestresultsfiles;
+ protected SynchronizedObservableCollection<RmlExtensionTestWashingResult> _rmlextensiontestwashingresults;
/// <summary>
/// Gets or sets the rmlextensiontestresultbase rml extension test results files.
/// </summary>
- public virtual SynchronizedObservableCollection<RmlExtensionTestResultsFile> RmlExtensionTestResultsFiles
+ public virtual SynchronizedObservableCollection<RmlExtensionTestWashingResult> RmlExtensionTestWashingResults
{
get
{
- return _rmlextensiontestresultsfiles;
+ return _rmlextensiontestwashingresults;
}
set
{
- if (_rmlextensiontestresultsfiles != value)
+ if (_rmlextensiontestwashingresults != value)
{
- _rmlextensiontestresultsfiles = value;
+ _rmlextensiontestwashingresults = value;
- OnRmlExtensionTestResultsFilesChanged(value);
+ OnRmlExtensionTestWashingResultsChanged(value);
}
}
@@ -1387,6 +1414,15 @@ namespace Tango.BL.Entities
}
/// <summary>
+ /// Called when the RmlExtensionTestResultsFiles has changed.
+ /// </summary>
+ protected virtual void OnRmlExtensionTestResultsFilesChanged(SynchronizedObservableCollection<RmlExtensionTestResultsFile> rmlextensiontestresultsfiles)
+ {
+ RmlExtensionTestResultsFilesChanged?.Invoke(this, rmlextensiontestresultsfiles);
+ RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ }
+
+ /// <summary>
/// Called when the Machine has changed.
/// </summary>
protected virtual void OnMachineChanged(Machine machine)
@@ -1396,12 +1432,12 @@ namespace Tango.BL.Entities
}
/// <summary>
/// Called when the RmlExtensionTestResultsFiles has changed.
/// </summary>
- protected virtual void OnRmlExtensionTestResultsFilesChanged(SynchronizedObservableCollection<RmlExtensionTestResultsFile> rmlextensiontestresultsfiles)
+ protected virtual void OnRmlExtensionTestWashingResultsChanged(SynchronizedObservableCollection<RmlExtensionTestWashingResult> rmlextensiontestwashingresults)
{
- RmlExtensionTestResultsFilesChanged?.Invoke(this, rmlextensiontestresultsfiles);
- RaisePropertyChanged(nameof(RmlExtensionTestResultsFiles));
+ RmlExtensionTestWashingResultsChanged?.Invoke(this, rmlextensiontestwashingresults);
+ RaisePropertyChanged(nameof(RmlExtensionTestWashingResults));
}
/// <summary>
@@ -1423,6 +1459,8 @@ namespace Tango.BL.Entities
RmlExtensionTestResultsFiles = new SynchronizedObservableCollection<RmlExtensionTestResultsFile>();
+ RmlExtensionTestWashingResults = new SynchronizedObservableCollection<RmlExtensionTestWashingResult>();
+
RubbingResults = new SynchronizedObservableCollection<RubbingResult>();
}
@@ -1048,26 +1075,26 @@ namespace Tango.BL.Entities
/// <summary>
- /// Gets or sets the rmlextensiontestresultbase rml extension test results files.
+ /// Gets or sets the rmlextensiontestresultbase rml extension test washing results.
/// </summary>
@@ -1396,12 +1432,12 @@ namespace Tango.BL.Entities
}
/// <summary>
- /// Called when the RmlExtensionTestResultsFiles has changed.
+ /// Called when the RmlExtensionTestWashingResults has changed.
/// </summary>